@@ -1,6 +1,6 @@
 /* exif-data-tag.h
  *
- * Copyright  2005 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright (c) 2005 Lutz Mueller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,27 +14,35 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef __EXIF_DATA_TYPE_H__
-#define __EXIF_DATA_TYPE_H__
+#ifndef LIBEXIF_EXIF_DATA_TYPE_H
+#define LIBEXIF_EXIF_DATA_TYPE_H
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+/*! Represents the type of image data to which the EXIF data applies.
+ * The EXIF tags have different constraints depending on the type of
+ * image data.
+ */
 typedef enum {
 	EXIF_DATA_TYPE_UNCOMPRESSED_CHUNKY = 0,
 	EXIF_DATA_TYPE_UNCOMPRESSED_PLANAR,
 	EXIF_DATA_TYPE_UNCOMPRESSED_YCC,
 	EXIF_DATA_TYPE_COMPRESSED,
-	EXIF_DATA_TYPE_COUNT
+	EXIF_DATA_TYPE_COUNT,
+
+	EXIF_DATA_TYPE_UNKNOWN = EXIF_DATA_TYPE_COUNT
 } ExifDataType;
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
-#endif /* __EXIF_TAG_H__ */
+#endif /* !defined(LIBEXIF_EXIF_DATA_TYPE_H) */
